# -*- coding: utf-8 -*-
from decimal import Decimal

TWO = Decimal(10) ** -2


def frac_to_dec(numerator: int = 1, detonator: int = 1) -> Decimal:
    """

    :param numerator: int
    :param detonator: int
    :return: dec_odds: Decimal odds
    """
    dec_odds = Decimal((numerator / detonator) + 1).quantize(TWO)
    return dec_odds


def pro_to_dec(probability: float = 1.00) -> Decimal:
    """

    :param probability:
    :return: dec_odds: Decimal odds
    """
    dec_odds = Decimal(100 / probability).quantize(TWO)
    return dec_odds


def us_to_dec(odds: int = 100) -> Decimal:
    """

    :param odds: int value of American odds positive or negative
    :return: dec_odds: Decimal odds
    """
    if odds >= 0:
        dec_odds = Decimal((odds / 100) + 1).quantize(TWO)
    else:
        dec_odds = Decimal((100 / abs(odds)) + 1).quantize(TWO)
    return dec_odds


def mal_to_dec(odds: float = 1) -> Decimal:
    """

    :param odds: float value of Malay odds positive or negative
    :return: dec_odds: Decimal odds
    """
    if odds >= 0:
        dec_odds = Decimal(odds + 1).quantize(TWO)
    else:
        dec_odds = Decimal(1 + (1 / abs(odds))).quantize(TWO)
    return dec_odds


def hk_to_dec(odds: float = 1.00) -> Decimal:
    """

    :param odds: float Hong Kong odds
    :return: dec_odds: Decimal odds
    """
    dec_odds = Decimal(odds + 1).quantize(TWO)
    return dec_odds


def ind_to_dec(odds=1.00):
    """

    :param odds: float value of Indonesian odds positive or negative
    :return: dec_odds: Decimal odds
    """
    if odds >= 0:
        dec_odds = Decimal(odds + 1).quantize(TWO)
    else:
        dec_odds = Decimal(1 + (1 / abs(odds))).quantize(TWO)
    return dec_odds





#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `converter` package."""

from pytest import approx

from decimal import Decimal

from surebet import converter


def test_frac_to_dec():
    assert converter.frac_to_dec(numerator=36, detonator=5) == approx(Decimal(8.20))


def test_pro_to_dec():
    assert converter.pro_to_dec(probability=68) == approx(Decimal(1.47))


def test_us_to_dec():
    assert converter.us_to_dec(odds=205) == approx(Decimal(3.05))
    assert converter.us_to_dec(odds=-200) == approx(Decimal(1.50))


def test_mal_to_dec():
    assert converter.mal_to_dec(odds=0.87) == approx(Decimal(1.87))
    assert converter.mal_to_dec(odds=-.60) == approx(Decimal(2.67))


def test_hk_to_dec():
    assert converter.hk_to_dec(odds=0.87) == approx(Decimal(1.87))


def test_ind_to_dec():
    assert converter.ind_to_dec(odds=5.21) == approx(Decimal(6.21))
    assert converter.ind_to_dec(odds=-2.60) == approx(Decimal(1.38))



# -*- coding: utf-8 -*-

"""Console script for surebet."""
import argparse


if __name__ == "__main__":

    parser = argparse.ArgumentParser()

    # define each option with: parser.add_argument

    args = parser.parse_args()  # automatically looks at sys.argv

    # access results with: args.argumentName
